==> openGion7.2.6.1_dev.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GEA05S.sql <==
/****************************************************************************/
/* GEA05 ( ﾛｰﾙﾏｽﾀ )                                                         */
/*                                                                          */
/* Created : 2018/09/28 16:03:25                                            */
/****************************************************************************/

CREATE TABLE GEA05 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL                                                /*  10 ｼｽﾃﾑID   */
 , ROLES        TEXT                                                                                    /*  20 ﾛｰﾙｽﾞ    */
 , NMROLE       VARCHAR ( 200 )                                                                         /*  30 ﾛｰﾙ名称  */
 , KBROLE       VARCHAR (   1 )     DEFAULT '1' NOT NULL                                                /*  40 ﾛｰﾙ区分  */
 , UNIQ         BIGINT                          NOT NULL    AUTO_INCREMENT  , PRIMARY KEY(UNIQ)         /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL                                                /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR (  14 )                                                                         /* 820 登録日時 */
 , PGSET        VARCHAR (  10 )                                                                         /* 830 作成PG   */
 , PGPSET       VARCHAR (  10 )                                                                         /* 840 作成親PG */
 , USRSET       VARCHAR (  10 )                                                                         /* 850 作成者   */
 , DYUPD        VARCHAR (  14 )                                                                         /* 860 更新日時 */
 , PGUPD        VARCHAR (  10 )                                                                         /* 870 更新PG   */
 , PGPUPD       VARCHAR (  10 )                                                                         /* 880 更新親PG */
 , USRUPD       VARCHAR (  10 )                                                                         /* 890 更新者   */
);

==> openGion7.3.0.1_dev.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GEA05S.sql <==
/****************************************************************************/
/* GEA05 ( ﾛｰﾙﾏｽﾀ )                                                         */
/*                                                                          */
/* Created : 2020/12/16 08:14:03                                            */
/****************************************************************************/

CREATE TABLE GEA05 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL                                                /*  10 ｼｽﾃﾑID   */
 , ROLES        TEXT                                                                                    /*  20 ﾛｰﾙｽﾞ    */
 , NMROLE       VARCHAR ( 200 )                                                                         /*  30 ﾛｰﾙ名称  */
 , KBROLE       VARCHAR (   1 )     DEFAULT '1' NOT NULL                                                /*  40 ﾛｰﾙ区分  */
 , UNIQ         BIGINT                          NOT NULL    AUTO_INCREMENT  , PRIMARY KEY(UNIQ)         /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL                                                /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR (  14 )                                                                         /* 820 作成日時 */
 , PGSET        VARCHAR (  10 )                                                                         /* 830 作成PG   */
 , PGPSET       VARCHAR (  10 )                                                                         /* 840 作成親PG */
 , USRSET       VARCHAR (  10 )                                                                         /* 850 作成者   */
 , DYUPD        VARCHAR (  14 )                                                                         /* 860 更新日時 */
 , PGUPD        VARCHAR (  10 )                                                                         /* 870 更新PG   */
 , PGPUPD       VARCHAR (  10 )                                                                         /* 880 更新親PG */
 , USRUPD       VARCHAR (  10 )                                                                         /* 890 更新者   */
);
